/**
 * S-Expression Parser
 */
export default class SParser {
    /**
     * Recursively parses s-expressions into arrays
     * @param stream s-expression string
     */
    static parse(stream: string): string | string[];
    /**
     * Current Line
     */
    private _line;
    /**
     * Current Column
     */
    private _col;
    /**
     * Current Position
     */
    private _pos;
    /**
     * String to parse
     */
    private _stream;
    /**
     * Instantiates a new SParser
     * @param stream s-expression string
     */
    constructor(stream: string);
    /**
     * Returns the next character
     */
    peek(): string;
    /**
     * Returns the next character and advances the counter, if a new line is detected, return it as well
     */
    consume(): string;
    /**
     * Parse the string until a regex is encountered and return the parsed substring
     * @param regex matcher look for
     */
    until(regex: RegExp): string;
    /**
     * parse until string section ends and return the string
     */
    string(): string;
    /**
     * Returns the next atom
     */
    atom(): string;
    /**
     * Returns the next quoted
     */
    quoted(): (string | string[])[];
    /**
     * returns the next expression
     */
    expr(): string[] | string;
    /**
     * returns the next list
     */
    list(): string[] | string[][];
}
